@@ -53,6 +53,8 @@ def report_error(title=None, data={}, caught=None, is_fatal=False):
     types of crashes: fatal crashes (backend errors) or non-fatal ones (just
     reporting a glitch, but the api call did not fail)"""
 
+    log.info("Caught error: %s\ndata=%s" % (title, json.dumps(data, indent=4)))
+
     # Don't report errors if NO_ERROR_REPORTING set to 1 (set by run_acceptance_tests)
     if os.environ.get('DO_REPORT_ERROR', None):
         # Force error reporting
@@ -189,12 +191,19 @@ def populate_error_report(data):
         }
 
         # Endpoint data
+        raw_data = ''
+        try:
+            raw_data = str(request.get_data())
+        except Exception:
+            pass
+
         data['endpoint'] = {
             'id': "%s %s %s" % (ApiPool().current_server_name, request.method, request.path),
             'url': request.url,
             'base_url': request.base_url,
             'path': request.path,
-            'method': request.method
+            'method': request.method,
+            'data': raw_data,
         }
 
 
